==> jc-1.4.0.tar.gz: java/security/AccessControlContext.h <==
// public final class java.security.AccessControlContext

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 31bcfe43cbef742c java_security_AccessControlContext

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_AccessControlContext_H_
#define _JC_java_security_AccessControlContext_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_security_AccessControlContext$object;
struct _jc_java_security_DomainCombiner$object;
struct _jc_java_security_Permission$object;

// Typedefs
typedef struct _jc_java_security_AccessControlContext$sub_refs	_jc_java_security_AccessControlContext$sub_refs;
typedef struct _jc_java_security_AccessControlContext$sub_nonrefs	_jc_java_security_AccessControlContext$sub_nonrefs;
typedef struct _jc_java_security_AccessControlContext$refs	_jc_java_security_AccessControlContext$refs;
typedef struct _jc_java_security_AccessControlContext$nonrefs	_jc_java_security_AccessControlContext$nonrefs;
typedef struct _jc_java_security_AccessControlContext$object	_jc_java_security_AccessControlContext$object;

typedef const struct _jc_java_security_AccessControlContext$vmethods	_jc_java_security_AccessControlContext$vmethods;
typedef const struct _jc_java_security_AccessControlContext$vtable	_jc_java_security_AccessControlContext$vtable;
typedef const struct _jc_java_security_AccessControlContext$vtype	_jc_java_security_AccessControlContext$vtype;

// Constructors
extern void _jc_java_security_AccessControlContext$method$_init$c19560f565719a5e(_jc_env *, struct _jc_java_security_AccessControlContext$object *, struct _jc_java_security_AccessControlContext$object *, struct _jc_object *);
extern void _jc_java_security_AccessControlContext$method$_init$39a3604eaf478810(_jc_env *, struct _jc_java_security_AccessControlContext$object *, struct _jc_object_array *);
extern void _jc_java_security_AccessControlContext$method$_init$c502e2cec9be7b42(_jc_env *, struct _jc_java_security_AccessControlContext$object *, struct _jc_object_array *, struct _jc_java_security_AccessControlContext$object *, struct _jc_object *);

// Virtual methods
extern void _jc_java_security_AccessControlContext$method$checkPermission$c9030844da652e90(_jc_env *, struct _jc_java_security_AccessControlContext$object *, struct _jc_java_security_Permission$object *);
extern jboolean _jc_java_security_AccessControlContext$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_security_AccessControlContext$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_java_security_AccessControlContext$method$getDomainCombiner$e327d5c1b4488448(_jc_env *, struct _jc_java_security_AccessControlContext$object *);
extern jint _jc_java_security_AccessControlContext$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_security_AccessControlContext$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_AccessControlContext$method_info$checkPermission$c9030844da652e90;
extern _jc_method _jc_java_security_AccessControlContext$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_security_AccessControlContext$method_info$getDomainCombiner$e327d5c1b4488448;
extern _jc_method _jc_java_security_AccessControlContext$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_java_security_AccessControlContext$vmethods {
	void	(*checkPermission$c9030844da652e90)(_jc_env *, struct _jc_java_security_AccessControlContext$object *, struct _jc_java_security_Permission$object *);
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_security_AccessControlContext$object *, struct _jc_java_lang_Object$object *);
	struct _jc_object	*(*getDomainCombiner$e327d5c1b4488448)(_jc_env *, struct _jc_java_security_AccessControlContext$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_security_AccessControlContext$object *);
};

// Vtable
struct _jc_java_security_AccessControlContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_AccessControlContext$vmethods	java_security_AccessControlContext;
};

// Vtype
struct _jc_java_security_AccessControlContext$vtype {
	_jc_type			type;
	_jc_java_security_AccessControlContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_AccessControlContext$sub_refs {
	_jc_object_array	*protectionDomains;
	struct _jc_object	*combiner;
};

// Reference instance fields (object)
struct _jc_java_security_AccessControlContext$refs {
    _jc_java_security_AccessControlContext$sub_refs	java_security_AccessControlContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_AccessControlContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_AccessControlContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_AccessControlContext$sub_nonrefs	java_security_AccessControlContext;
};

// Object instance structure
struct _jc_java_security_AccessControlContext$object {
	_jc_java_security_AccessControlContext$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_AccessControlContext$vtype	*vtype;
	_jc_java_security_AccessControlContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_AccessControlContext$vtype _jc_java_security_AccessControlContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_AccessControlContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_AccessControlContext$class_object;

#endif	/* _JC_java_security_AccessControlContext_H_ */

==> jc-1.4.6.tar.gz: java/security/AccessControlContext.h <==
// public final class java.security.AccessControlContext

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 31bcfe43cbef742c java_security_AccessControlContext

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_AccessControlContext_H_
#define _JC_java_security_AccessControlContext_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_security_AccessControlContext$object;
struct _jc_java_security_DomainCombiner$object;
struct _jc_java_security_Permission$object;

// Typedefs
typedef struct _jc_java_security_AccessControlContext$sub_refs	_jc_java_security_AccessControlContext$sub_refs;
typedef struct _jc_java_security_AccessControlContext$sub_nonrefs	_jc_java_security_AccessControlContext$sub_nonrefs;
typedef struct _jc_java_security_AccessControlContext$refs	_jc_java_security_AccessControlContext$refs;
typedef struct _jc_java_security_AccessControlContext$nonrefs	_jc_java_security_AccessControlContext$nonrefs;
typedef struct _jc_java_security_AccessControlContext$object	_jc_java_security_AccessControlContext$object;

typedef const struct _jc_java_security_AccessControlContext$vmethods	_jc_java_security_AccessControlContext$vmethods;
typedef const struct _jc_java_security_AccessControlContext$vtable	_jc_java_security_AccessControlContext$vtable;
typedef const struct _jc_java_security_AccessControlContext$vtype	_jc_java_security_AccessControlContext$vtype;

// Constructors
extern void _jc_java_security_AccessControlContext$method$_init$c19560f565719a5e(_jc_env *, struct _jc_java_security_AccessControlContext$object *, struct _jc_java_security_AccessControlContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_java_security_AccessControlContext$method$_init$39a3604eaf478810(_jc_env *, struct _jc_java_security_AccessControlContext$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_java_security_AccessControlContext$method$_init$c502e2cec9be7b42(_jc_env *, struct _jc_java_security_AccessControlContext$object *, struct _jc_object_array *, struct _jc_java_security_AccessControlContext$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_security_AccessControlContext$method$checkPermission$c9030844da652e90(_jc_env *, struct _jc_java_security_AccessControlContext$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_security_AccessControlContext$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_security_AccessControlContext$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_security_AccessControlContext$method$getDomainCombiner$e327d5c1b4488448(_jc_env *, struct _jc_java_security_AccessControlContext$object *) _JC_JCNI_ATTR;
extern jint _jc_java_security_AccessControlContext$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_security_AccessControlContext$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_AccessControlContext$method_info$checkPermission$c9030844da652e90;
extern _jc_method _jc_java_security_AccessControlContext$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_security_AccessControlContext$method_info$getDomainCombiner$e327d5c1b4488448;
extern _jc_method _jc_java_security_AccessControlContext$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_java_security_AccessControlContext$vmethods {
	void	(*checkPermission$c9030844da652e90)(_jc_env *, struct _jc_java_security_AccessControlContext$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_security_AccessControlContext$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getDomainCombiner$e327d5c1b4488448)(_jc_env *, struct _jc_java_security_AccessControlContext$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_security_AccessControlContext$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_AccessControlContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_AccessControlContext$vmethods	java_security_AccessControlContext;
};

// Vtype
struct _jc_java_security_AccessControlContext$vtype {
	_jc_type			type;
	_jc_java_security_AccessControlContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_AccessControlContext$sub_refs {
	_jc_object_array	*protectionDomains;
	struct _jc_object	*combiner;
};

// Reference instance fields (object)
struct _jc_java_security_AccessControlContext$refs {
    _jc_java_security_AccessControlContext$sub_refs	java_security_AccessControlContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_AccessControlContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_AccessControlContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_AccessControlContext$sub_nonrefs	java_security_AccessControlContext;
};

// Object instance structure
struct _jc_java_security_AccessControlContext$object {
	_jc_java_security_AccessControlContext$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_AccessControlContext$vtype	*vtype;
	_jc_java_security_AccessControlContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_AccessControlContext$vtype _jc_java_security_AccessControlContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_AccessControlContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_AccessControlContext$class_object;

#endif	/* _JC_java_security_AccessControlContext_H_ */
